# Code generated by sqlc. DO NOT EDIT.
# versions:
#   sqlc v1.29.0
# source: _15_create_hyrex_kv_table.sql
import dataclasses

import sqlalchemy
import sqlalchemy.ext.asyncio

from . import models


CREATE_HYREX_KV_TABLE = """-- name: create_hyrex_kv_table \\:exec
CREATE TABLE IF NOT EXISTS hyrex_kv (
    key VARCHAR NOT NULL PRIMARY KEY,
    value TEXT NOT NULL,
    created_at TIMESTAMP WITH TIME ZONE NOT NULL DEFAULT CURRENT_TIMESTAMP
)
"""


@dataclasses.dataclass()
class CreateHyrexKvTableParams:

    pass

class Querier:
    def __init__(self, conn: sqlalchemy.engine.Connection):
        self._conn = conn

    def create_hyrex_kv_table(self, arg: CreateHyrexKvTableParams) -> None:
        self._conn.execute(sqlalchemy.text(CREATE_HYREX_KV_TABLE))


class AsyncQuerier:
    def __init__(self, conn: sqlalchemy.ext.asyncio.AsyncConnection):
        self._conn = conn

    async def create_hyrex_kv_table(self, arg: CreateHyrexKvTableParams) -> None:
        await self._conn.execute(sqlalchemy.text(CREATE_HYREX_KV_TABLE))
