# Code generated by sqlc. DO NOT EDIT.
# versions:
#   sqlc v1.29.0
# source: _02_create_hyrex_app_table.sql
import dataclasses

import sqlalchemy
import sqlalchemy.ext.asyncio

from . import models


CREATE_APP_TABLE = """-- name: create_app_table \\:exec
CREATE TABLE IF NOT EXISTS hyrex_app
(
    id       BIGSERIAL NOT NULL PRIMARY KEY,
    app_info JSON
)
"""


@dataclasses.dataclass()
class CreateAppTableParams:

    pass

class Querier:
    def __init__(self, conn: sqlalchemy.engine.Connection):
        self._conn = conn

    def create_app_table(self, arg: CreateAppTableParams) -> None:
        self._conn.execute(sqlalchemy.text(CREATE_APP_TABLE))


class AsyncQuerier:
    def __init__(self, conn: sqlalchemy.ext.asyncio.AsyncConnection):
        self._conn = conn

    async def create_app_table(self, arg: CreateAppTableParams) -> None:
        await self._conn.execute(sqlalchemy.text(CREATE_APP_TABLE))
