# Code generated by sqlc. DO NOT EDIT.
# versions:
#   sqlc v1.29.0
# source: flush_all_data.sql
import dataclasses

import sqlalchemy
import sqlalchemy.ext.asyncio

from . import models


FLUSH_ALL_DATA = """-- name: flush_all_data \\:exec
BEGIN
"""


@dataclasses.dataclass()
class FlushAllDataParams:

    pass

class Querier:
    def __init__(self, conn: sqlalchemy.engine.Connection):
        self._conn = conn

    def flush_all_data(self, arg: FlushAllDataParams) -> None:
        self._conn.execute(sqlalchemy.text(FLUSH_ALL_DATA))


class AsyncQuerier:
    def __init__(self, conn: sqlalchemy.ext.asyncio.AsyncConnection):
        self._conn = conn

    async def flush_all_data(self, arg: FlushAllDataParams) -> None:
        await self._conn.execute(sqlalchemy.text(FLUSH_ALL_DATA))
