# Code generated by sqlc. DO NOT EDIT.
# versions:
#   sqlc v1.29.0
# source: kv_flush_keys.sql
import dataclasses

import sqlalchemy
import sqlalchemy.ext.asyncio

from . import models


FLUSH_KEYS = """-- name: flush_keys \\:exec
DELETE FROM hyrex_kv
"""


@dataclasses.dataclass()
class FlushKeysParams:

    pass

class Querier:
    def __init__(self, conn: sqlalchemy.engine.Connection):
        self._conn = conn

    def flush_keys(self, arg: FlushKeysParams) -> None:
        self._conn.execute(sqlalchemy.text(FLUSH_KEYS))


class AsyncQuerier:
    def __init__(self, conn: sqlalchemy.ext.asyncio.AsyncConnection):
        self._conn = conn

    async def flush_keys(self, arg: FlushKeysParams) -> None:
        await self._conn.execute(sqlalchemy.text(FLUSH_KEYS))
