# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import requests_pb2 as requests__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rgateway.proto\x12\x17hyrex.performanceserver\x1a\x1bgoogle/protobuf/empty.proto\x1a\x0erequests.proto2\xf6\x19\n\x0eGatewayService\x12@\n\x0eTestConnection\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\x12N\n\tWriteLogs\x12).hyrex.performanceserver.WriteLogsRequest\x1a\x16.google.protobuf.Empty\x12J\n\x07\x45nqueue\x12\'.hyrex.performanceserver.EnqueueRequest\x1a\x16.google.protobuf.Empty\x12\\\n\x07\x44\x65queue\x12\'.hyrex.performanceserver.DequeueRequest\x1a(.hyrex.performanceserver.DequeueResponse\x12\x62\n\tGetQueues\x12).hyrex.performanceserver.GetQueuesRequest\x1a*.hyrex.performanceserver.GetQueuesResponse\x12w\n\x10GetTaskRunStatus\x12\x30.hyrex.performanceserver.GetTaskRunStatusRequest\x1a\x31.hyrex.performanceserver.GetTaskRunStatusResponse\x12R\n\x0bMarkSuccess\x12+.hyrex.performanceserver.MarkSuccessRequest\x1a\x16.google.protobuf.Empty\x12P\n\nMarkFailed\x12*.hyrex.performanceserver.MarkFailedRequest\x1a\x16.google.protobuf.Empty\x12\x65\n\nGetTaskRun\x12*.hyrex.performanceserver.GetTaskRunRequest\x1a+.hyrex.performanceserver.GetTaskRunResponse\x12}\n\x12GetDurableTaskRuns\x12\x32.hyrex.performanceserver.GetDurableTaskRunsRequest\x1a\x33.hyrex.performanceserver.GetDurableTaskRunsResponse\x12T\n\x0cRetryTaskRun\x12,.hyrex.performanceserver.RetryTaskRunRequest\x1a\x16.google.protobuf.Empty\x12\\\n\x10TaskRunHeartbeat\x12\x30.hyrex.performanceserver.TaskRunHeartbeatRequest\x1a\x16.google.protobuf.Empty\x12\x66\n\x15TryToCancelDurableRun\x12\x35.hyrex.performanceserver.TryToCancelDurableRunRequest\x1a\x16.google.protobuf.Empty\x12i\n\x16GetTaskRunsUpForCancel\x12\x16.google.protobuf.Empty\x1a\x37.hyrex.performanceserver.GetTaskRunsUpForCancelResponse\x12T\n\x0cMarkCanceled\x12,.hyrex.performanceserver.MarkCanceledRequest\x1a\x16.google.protobuf.Empty\x12P\n\nKVStoreSet\x12*.hyrex.performanceserver.KVStoreSetRequest\x1a\x16.google.protobuf.Empty\x12\x65\n\nKVStoreGet\x12*.hyrex.performanceserver.KVStoreGetRequest\x1a+.hyrex.performanceserver.KVStoreGetResponse\x12V\n\rKVStoreDelete\x12-.hyrex.performanceserver.KVStoreDeleteRequest\x1a\x16.google.protobuf.Empty\x12\x64\n\x14MarkRunningTasksLost\x12\x34.hyrex.performanceserver.MarkRunningTasksLostRequest\x1a\x16.google.protobuf.Empty\x12Z\n\x0fRegisterTaskDef\x12/.hyrex.performanceserver.RegisterTaskDefRequest\x1a\x16.google.protobuf.Empty\x12\x65\n\nGetTaskDef\x12*.hyrex.performanceserver.GetTaskDefRequest\x1a+.hyrex.performanceserver.GetTaskDefResponse\x12q\n\x0eGetAllTaskDefs\x12..hyrex.performanceserver.GetAllTaskDefsRequest\x1a/.hyrex.performanceserver.GetAllTaskDefsResponse\x12\\\n\x10RegisterExecutor\x12\x30.hyrex.performanceserver.RegisterExecutorRequest\x1a\x16.google.protobuf.Empty\x12^\n\x11\x45xecutorHeartbeat\x12\x31.hyrex.performanceserver.ExecutorHeartbeatRequest\x1a\x16.google.protobuf.Empty\x12\x62\n\x13UpdateExecutorStats\x12\x33.hyrex.performanceserver.UpdateExecutorStatsRequest\x1a\x16.google.protobuf.Empty\x12\x64\n\x14UpdateExecutorQueues\x12\x34.hyrex.performanceserver.UpdateExecutorQueuesRequest\x1a\x16.google.protobuf.Empty\x12`\n\x12\x44isconnectExecutor\x12\x32.hyrex.performanceserver.DisconnectExecutorRequest\x1a\x16.google.protobuf.Empty\x12R\n\x0bRegisterApp\x12+.hyrex.performanceserver.RegisterAppRequest\x1a\x16.google.protobuf.Empty\x12P\n\nSetLogLink\x12*.hyrex.performanceserver.SetLogLinkRequest\x1a\x16.google.protobuf.Empty\x12\\\n\x10RegisterWorkflow\x12\x30.hyrex.performanceserver.RegisterWorkflowRequest\x1a\x16.google.protobuf.Empty\x12Z\n\x0fSendWorkflowRun\x12/.hyrex.performanceserver.SendWorkflowRunRequest\x1a\x16.google.protobuf.Empty\x12}\n\x12GetWorkflowRunArgs\x12\x32.hyrex.performanceserver.GetWorkflowRunArgsRequest\x1a\x33.hyrex.performanceserver.GetWorkflowRunArgsResponse\x12`\n\x12\x41\x64vanceWorkflowRun\x12\x32.hyrex.performanceserver.AdvanceWorkflowRunRequest\x1a\x16.google.protobuf.Empty\x12\x89\x01\n\x16GetWorkflowDurableRuns\x12\x36.hyrex.performanceserver.GetWorkflowDurableRunsRequest\x1a\x37.hyrex.performanceserver.GetWorkflowDurableRunsResponseB\x08Z\x06proto/b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\006proto/'
  _globals['_GATEWAYSERVICE']._serialized_start=88
  _globals['_GATEWAYSERVICE']._serialized_end=3406
# @@protoc_insertion_point(module_scope)
