# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: requests.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'requests.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from . import task_pb2 as task__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0erequests.proto\x12\x17hyrex.performanceserver\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\ntask.proto\"\x94\x04\n\x0e\x45nqueueRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\ndurable_id\x18\x02 \x01(\t\x12\x0f\n\x07root_id\x18\x03 \x01(\t\x12\x1c\n\x0fworkflow_run_id\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x1d\n\x15workflow_dependencies\x18\x05 \x03(\t\x12\x16\n\tparent_id\x18\x06 \x01(\tH\x01\x88\x01\x01\x12\x11\n\ttask_name\x18\x07 \x01(\t\x12\x0c\n\x04\x61rgs\x18\x08 \x01(\x0c\x12\r\n\x05queue\x18\t \x01(\t\x12\x13\n\x0bmax_retries\x18\n \x01(\x05\x12\x1b\n\x0e\x61ttempt_number\x18\x0b \x01(\x05H\x02\x88\x01\x01\x12\x33\n\x08priority\x18\x0c \x01(\x0e\x32!.hyrex.performanceserver.Priority\x12\x1c\n\x0ftimeout_seconds\x18\r \x01(\x05H\x03\x88\x01\x01\x12\x1c\n\x0fidempotency_key\x18\x0e \x01(\tH\x04\x88\x01\x01\x12\x38\n\x0fscheduled_start\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x05\x88\x01\x01\x42\x12\n\x10_workflow_run_idB\x0c\n\n_parent_idB\x11\n\x0f_attempt_numberB\x12\n\x10_timeout_secondsB\x12\n\x10_idempotency_keyB\x12\n\x10_scheduled_start\"4\n\x0e\x44\x65queueRequest\x12\x13\n\x0b\x65xecutor_id\x18\x01 \x01(\t\x12\r\n\x05queue\x18\x02 \x01(\t\"E\n\x0f\x44\x65queueResponse\x12\x32\n\x08task_run\x18\x01 \x01(\x0b\x32 .hyrex.performanceserver.TaskRun\";\n\x10GetQueuesRequest\x12\x16\n\x0emax_num_queues\x18\x01 \x01(\x05\x12\x0f\n\x07pattern\x18\x02 \x01(\t\"4\n\x11GetQueuesResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0e\n\x06queues\x18\x02 \x03(\t\"C\n\x13RetryTaskRunRequest\x12\x13\n\x0btask_run_id\x18\x01 \x01(\t\x12\x17\n\x0f\x62\x61\x63koff_seconds\x18\x02 \x01(\x05\"(\n\x11GetTaskRunRequest\x12\x13\n\x0btask_run_id\x18\x01 \x01(\t\"H\n\x12GetTaskRunResponse\x12\x32\n\x08task_run\x18\x01 \x01(\x0b\x32 .hyrex.performanceserver.TaskRun\".\n\x17GetTaskRunStatusRequest\x12\x13\n\x0btask_run_id\x18\x01 \x01(\t\"O\n\x18GetTaskRunStatusResponse\x12\x33\n\x06status\x18\x01 \x01(\x0e\x32#.hyrex.performanceserver.TaskStatus\"^\n\x17TaskRunHeartbeatRequest\x12\x14\n\x0ctask_run_ids\x18\x01 \x03(\t\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"I\n\x12MarkSuccessRequest\x12\x13\n\x0btask_run_id\x18\x01 \x01(\t\x12\x13\n\x06result\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\t\n\x07_result\"(\n\x11MarkFailedRequest\x12\x13\n\x0btask_run_id\x18\x01 \x01(\t\"/\n\x19GetDurableTaskRunsRequest\x12\x12\n\ndurable_id\x18\x01 \x01(\t\"Q\n\x1aGetDurableTaskRunsResponse\x12\x33\n\ttask_runs\x18\x02 \x03(\x0b\x32 .hyrex.performanceserver.TaskRun\":\n\x11SetLogLinkRequest\x12\x13\n\x0btask_run_id\x18\x01 \x01(\t\x12\x10\n\x08log_link\x18\x02 \x01(\t\"L\n\x16RegisterTaskDefRequest\x12\x32\n\x08task_def\x18\x01 \x01(\x0b\x32 .hyrex.performanceserver.TaskDef\"&\n\x11GetTaskDefRequest\x12\x11\n\ttask_name\x18\x01 \x01(\t\"H\n\x12GetTaskDefResponse\x12\x32\n\x08task_def\x18\x01 \x01(\x0b\x32 .hyrex.performanceserver.TaskDef\"\x17\n\x15GetAllTaskDefsRequest\"M\n\x16GetAllTaskDefsResponse\x12\x33\n\ttask_defs\x18\x01 \x03(\x0b\x32 .hyrex.performanceserver.TaskDef\"\x15\n\x13RegisterCronRequest\"\x81\x01\n\x17RegisterExecutorRequest\x12\x13\n\x0b\x65xecutor_id\x18\x01 \x01(\t\x12\x15\n\rexecutor_name\x18\x02 \x01(\t\x12\x15\n\rqueue_pattern\x18\x03 \x01(\t\x12\x0e\n\x06queues\x18\x04 \x03(\t\x12\x13\n\x0bworker_name\x18\x05 \x01(\t\"B\n\x1bUpdateExecutorQueuesRequest\x12\x13\n\x0b\x65xecutor_id\x18\x01 \x01(\t\x12\x0e\n\x06queues\x18\x02 \x03(\t\"b\n\x1aUpdateExecutorStatsRequest\x12\x13\n\x0b\x65xecutor_id\x18\x01 \x01(\t\x12/\n\x0e\x65xecutor_stats\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"_\n\x18\x45xecutorHeartbeatRequest\x12\x14\n\x0c\x65xecutor_ids\x18\x01 \x03(\t\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"0\n\x19\x44isconnectExecutorRequest\x12\x13\n\x0b\x65xecutor_id\x18\x01 \x01(\t\"2\n\x1bMarkRunningTasksLostRequest\x12\x13\n\x0b\x65xecutor_id\x18\x01 \x01(\t\"?\n\x12RegisterAppRequest\x12)\n\x08\x61pp_info\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"5\n\x10WriteLogsRequest\x12\x13\n\x0btask_run_id\x18\x01 \x01(\t\x12\x0c\n\x04logs\x18\x02 \x01(\t\"\x80\x02\n\x17RegisterWorkflowRequest\x12\x15\n\rworkflow_name\x18\x01 \x01(\t\x12\x13\n\x0bsource_code\x18\x02 \x01(\t\x12\x19\n\x11workflow_dag_json\x18\x03 \x01(\t\x12\x39\n\x13workflow_arg_schema\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x88\x01\x01\x12/\n\x0e\x64\x65\x66\x61ult_config\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\x04\x63ron\x18\x06 \x01(\tH\x01\x88\x01\x01\x42\x16\n\x14_workflow_arg_schemaB\x07\n\x05_cron\"\xe2\x01\n\x16SendWorkflowRunRequest\x12\x17\n\x0fworkflow_run_id\x18\x01 \x01(\t\x12\x15\n\rworkflow_name\x18\x02 \x01(\t\x12%\n\x04\x61rgs\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\r\n\x05queue\x18\x04 \x01(\t\x12\x1c\n\x0ftimeout_seconds\x18\x05 \x01(\x05H\x00\x88\x01\x01\x12\x1c\n\x0fidempotency_key\x18\x06 \x01(\tH\x01\x88\x01\x01\x42\x12\n\x10_timeout_secondsB\x12\n\x10_idempotency_key\"4\n\x19GetWorkflowRunArgsRequest\x12\x17\n\x0fworkflow_run_id\x18\x01 \x01(\t\"C\n\x1aGetWorkflowRunArgsResponse\x12%\n\x04\x61rgs\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"4\n\x19\x41\x64vanceWorkflowRunRequest\x12\x17\n\x0fworkflow_run_id\x18\x01 \x01(\t\"8\n\x1dGetWorkflowDurableRunsRequest\x12\x17\n\x0fworkflow_run_id\x18\x01 \x01(\t\"5\n\x1eGetWorkflowDurableRunsResponse\x12\x13\n\x0b\x64urable_ids\x18\x01 \x03(\t\"2\n\x1cTryToCancelDurableRunRequest\x12\x12\n\ndurable_id\x18\x01 \x01(\t\"6\n\x1eGetTaskRunsUpForCancelResponse\x12\x14\n\x0ctask_run_ids\x18\x01 \x03(\t\"*\n\x13MarkCanceledRequest\x12\x13\n\x0btask_run_id\x18\x01 \x01(\t\"U\n\x11KVStoreSetRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x16\n\toverwrite\x18\x03 \x01(\x08H\x00\x88\x01\x01\x42\x0c\n\n_overwrite\" \n\x11KVStoreGetRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\"#\n\x12KVStoreGetResponse\x12\r\n\x05value\x18\x01 \x01(\t\"#\n\x14KVStoreDeleteRequest\x12\x0b\n\x03key\x18\x01 \x01(\tB\x08Z\x06proto/b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'requests_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\006proto/'
  _globals['_ENQUEUEREQUEST']._serialized_start=119
  _globals['_ENQUEUEREQUEST']._serialized_end=651
  _globals['_DEQUEUEREQUEST']._serialized_start=653
  _globals['_DEQUEUEREQUEST']._serialized_end=705
  _globals['_DEQUEUERESPONSE']._serialized_start=707
  _globals['_DEQUEUERESPONSE']._serialized_end=776
  _globals['_GETQUEUESREQUEST']._serialized_start=778
  _globals['_GETQUEUESREQUEST']._serialized_end=837
  _globals['_GETQUEUESRESPONSE']._serialized_start=839
  _globals['_GETQUEUESRESPONSE']._serialized_end=891
  _globals['_RETRYTASKRUNREQUEST']._serialized_start=893
  _globals['_RETRYTASKRUNREQUEST']._serialized_end=960
  _globals['_GETTASKRUNREQUEST']._serialized_start=962
  _globals['_GETTASKRUNREQUEST']._serialized_end=1002
  _globals['_GETTASKRUNRESPONSE']._serialized_start=1004
  _globals['_GETTASKRUNRESPONSE']._serialized_end=1076
  _globals['_GETTASKRUNSTATUSREQUEST']._serialized_start=1078
  _globals['_GETTASKRUNSTATUSREQUEST']._serialized_end=1124
  _globals['_GETTASKRUNSTATUSRESPONSE']._serialized_start=1126
  _globals['_GETTASKRUNSTATUSRESPONSE']._serialized_end=1205
  _globals['_TASKRUNHEARTBEATREQUEST']._serialized_start=1207
  _globals['_TASKRUNHEARTBEATREQUEST']._serialized_end=1301
  _globals['_MARKSUCCESSREQUEST']._serialized_start=1303
  _globals['_MARKSUCCESSREQUEST']._serialized_end=1376
  _globals['_MARKFAILEDREQUEST']._serialized_start=1378
  _globals['_MARKFAILEDREQUEST']._serialized_end=1418
  _globals['_GETDURABLETASKRUNSREQUEST']._serialized_start=1420
  _globals['_GETDURABLETASKRUNSREQUEST']._serialized_end=1467
  _globals['_GETDURABLETASKRUNSRESPONSE']._serialized_start=1469
  _globals['_GETDURABLETASKRUNSRESPONSE']._serialized_end=1550
  _globals['_SETLOGLINKREQUEST']._serialized_start=1552
  _globals['_SETLOGLINKREQUEST']._serialized_end=1610
  _globals['_REGISTERTASKDEFREQUEST']._serialized_start=1612
  _globals['_REGISTERTASKDEFREQUEST']._serialized_end=1688
  _globals['_GETTASKDEFREQUEST']._serialized_start=1690
  _globals['_GETTASKDEFREQUEST']._serialized_end=1728
  _globals['_GETTASKDEFRESPONSE']._serialized_start=1730
  _globals['_GETTASKDEFRESPONSE']._serialized_end=1802
  _globals['_GETALLTASKDEFSREQUEST']._serialized_start=1804
  _globals['_GETALLTASKDEFSREQUEST']._serialized_end=1827
  _globals['_GETALLTASKDEFSRESPONSE']._serialized_start=1829
  _globals['_GETALLTASKDEFSRESPONSE']._serialized_end=1906
  _globals['_REGISTERCRONREQUEST']._serialized_start=1908
  _globals['_REGISTERCRONREQUEST']._serialized_end=1929
  _globals['_REGISTEREXECUTORREQUEST']._serialized_start=1932
  _globals['_REGISTEREXECUTORREQUEST']._serialized_end=2061
  _globals['_UPDATEEXECUTORQUEUESREQUEST']._serialized_start=2063
  _globals['_UPDATEEXECUTORQUEUESREQUEST']._serialized_end=2129
  _globals['_UPDATEEXECUTORSTATSREQUEST']._serialized_start=2131
  _globals['_UPDATEEXECUTORSTATSREQUEST']._serialized_end=2229
  _globals['_EXECUTORHEARTBEATREQUEST']._serialized_start=2231
  _globals['_EXECUTORHEARTBEATREQUEST']._serialized_end=2326
  _globals['_DISCONNECTEXECUTORREQUEST']._serialized_start=2328
  _globals['_DISCONNECTEXECUTORREQUEST']._serialized_end=2376
  _globals['_MARKRUNNINGTASKSLOSTREQUEST']._serialized_start=2378
  _globals['_MARKRUNNINGTASKSLOSTREQUEST']._serialized_end=2428
  _globals['_REGISTERAPPREQUEST']._serialized_start=2430
  _globals['_REGISTERAPPREQUEST']._serialized_end=2493
  _globals['_WRITELOGSREQUEST']._serialized_start=2495
  _globals['_WRITELOGSREQUEST']._serialized_end=2548
  _globals['_REGISTERWORKFLOWREQUEST']._serialized_start=2551
  _globals['_REGISTERWORKFLOWREQUEST']._serialized_end=2807
  _globals['_SENDWORKFLOWRUNREQUEST']._serialized_start=2810
  _globals['_SENDWORKFLOWRUNREQUEST']._serialized_end=3036
  _globals['_GETWORKFLOWRUNARGSREQUEST']._serialized_start=3038
  _globals['_GETWORKFLOWRUNARGSREQUEST']._serialized_end=3090
  _globals['_GETWORKFLOWRUNARGSRESPONSE']._serialized_start=3092
  _globals['_GETWORKFLOWRUNARGSRESPONSE']._serialized_end=3159
  _globals['_ADVANCEWORKFLOWRUNREQUEST']._serialized_start=3161
  _globals['_ADVANCEWORKFLOWRUNREQUEST']._serialized_end=3213
  _globals['_GETWORKFLOWDURABLERUNSREQUEST']._serialized_start=3215
  _globals['_GETWORKFLOWDURABLERUNSREQUEST']._serialized_end=3271
  _globals['_GETWORKFLOWDURABLERUNSRESPONSE']._serialized_start=3273
  _globals['_GETWORKFLOWDURABLERUNSRESPONSE']._serialized_end=3326
  _globals['_TRYTOCANCELDURABLERUNREQUEST']._serialized_start=3328
  _globals['_TRYTOCANCELDURABLERUNREQUEST']._serialized_end=3378
  _globals['_GETTASKRUNSUPFORCANCELRESPONSE']._serialized_start=3380
  _globals['_GETTASKRUNSUPFORCANCELRESPONSE']._serialized_end=3434
  _globals['_MARKCANCELEDREQUEST']._serialized_start=3436
  _globals['_MARKCANCELEDREQUEST']._serialized_end=3478
  _globals['_KVSTORESETREQUEST']._serialized_start=3480
  _globals['_KVSTORESETREQUEST']._serialized_end=3565
  _globals['_KVSTOREGETREQUEST']._serialized_start=3567
  _globals['_KVSTOREGETREQUEST']._serialized_end=3599
  _globals['_KVSTOREGETRESPONSE']._serialized_start=3601
  _globals['_KVSTOREGETRESPONSE']._serialized_end=3636
  _globals['_KVSTOREDELETEREQUEST']._serialized_start=3638
  _globals['_KVSTOREDELETEREQUEST']._serialized_end=3673
# @@protoc_insertion_point(module_scope)
