class EnvVars:
    DATABASE_URL = "HYREX_DATABASE_URL"
    API_KEY = "HYREX_API_KEY"
    WORKER_PROCESS = "HYREX_WORKER_PROCESS"
    LOGS_BUCKET = "HYREX_S3_LOG_BUCKET"
    PERF_SERVER_HOST = "HYREX_PERFORMANCE_SERVER_HOST"
    PERF_SERVER_PORT = "HYREX_PERFORMANCE_SERVER_PORT"
    LOCAL_TESTING = "HYREX_LOCAL_TESTING"
