# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: task.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'task.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\ntask.proto\x12\x17hyrex.performanceserver\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xa3\x05\n\x07TaskRun\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\ndurable_id\x18\x02 \x01(\t\x12\x0f\n\x07root_id\x18\x03 \x01(\t\x12\x11\n\tparent_id\x18\x04 \x01(\t\x12\x11\n\ttask_name\x18\x05 \x01(\t\x12\x33\n\x06status\x18\x06 \x01(\x0e\x32#.hyrex.performanceserver.TaskStatus\x12\x0c\n\x04\x61rgs\x18\x07 \x01(\x0c\x12\r\n\x05queue\x18\x08 \x01(\t\x12\x33\n\x08priority\x18\t \x01(\x0e\x32!.hyrex.performanceserver.Priority\x12\x1c\n\x0ftimeout_seconds\x18\n \x01(\x05H\x00\x88\x01\x01\x12\x38\n\x0fscheduled_start\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01\x88\x01\x01\x12*\n\x06queued\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07started\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x66inished\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1c\n\x0fworkflow_run_id\x18\x0f \x01(\tH\x02\x88\x01\x01\x12\x1d\n\x15workflow_dependencies\x18\x10 \x03(\t\x12\x16\n\x0e\x61ttempt_number\x18\x11 \x01(\x05\x12\x13\n\x0bmax_retries\x18\x12 \x01(\x05\x12\x0e\n\x06result\x18\x13 \x01(\t\x12\x10\n\x08log_link\x18\x14 \x01(\t\x12\x13\n\x0b\x65xecutor_id\x18\x15 \x01(\tB\x12\n\x10_timeout_secondsB\x12\n\x10_scheduled_startB\x12\n\x10_workflow_run_id\"\xf6\x02\n\x07TaskDef\x12\x11\n\ttask_name\x18\x01 \x01(\t\x12\x30\n\narg_schema\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x88\x01\x01\x12\x11\n\x04\x63ron\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x18\n\x0bsource_code\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\r\n\x05queue\x18\x05 \x01(\t\x12\x33\n\x08priority\x18\x06 \x01(\x0e\x32!.hyrex.performanceserver.Priority\x12\x13\n\x0bmax_retries\x18\x07 \x01(\x05\x12\x1c\n\x0ftimeout_seconds\x18\x08 \x01(\x05H\x03\x88\x01\x01\x12\x35\n\x0clast_updated\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x04\x88\x01\x01\x42\r\n\x0b_arg_schemaB\x07\n\x05_cronB\x0e\n\x0c_source_codeB\x12\n\x10_timeout_secondsB\x0f\n\r_last_updated*n\n\x08Priority\x12\x11\n\rP_UNSPECIFIED\x10\x00\x12\x06\n\x02P1\x10\x01\x12\x06\n\x02P2\x10\x02\x12\x06\n\x02P3\x10\x03\x12\x06\n\x02P4\x10\x04\x12\x06\n\x02P5\x10\x05\x12\x06\n\x02P6\x10\x06\x12\x06\n\x02P7\x10\x07\x12\x06\n\x02P8\x10\x08\x12\x06\n\x02P9\x10\t\x12\x07\n\x03P10\x10\n*\xba\x01\n\nTaskStatus\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\x12\x0b\n\x07RUNNING\x10\x03\x12\n\n\x06QUEUED\x10\x04\x12\x11\n\rUP_FOR_CANCEL\x10\x05\x12\x0c\n\x08\x43\x41NCELED\x10\x06\x12\x08\n\x04LOST\x10\x07\x12\x0b\n\x07STOPPED\x10\x08\x12\x0b\n\x07SKIPPED\x10\t\x12\x0e\n\nAWAIT_DEPS\x10\n\x12\x14\n\x10\x41WAIT_START_TIME\x10\x0b\x42\x08Z\x06proto/b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'task_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\006proto/'
  _globals['_PRIORITY']._serialized_start=1157
  _globals['_PRIORITY']._serialized_end=1267
  _globals['_TASKSTATUS']._serialized_start=1270
  _globals['_TASKSTATUS']._serialized_end=1456
  _globals['_TASKRUN']._serialized_start=103
  _globals['_TASKRUN']._serialized_end=778
  _globals['_TASKDEF']._serialized_start=781
  _globals['_TASKDEF']._serialized_end=1155
# @@protoc_insertion_point(module_scope)
